==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
var WebTabDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabDescriptionMetadata, _super);
    function WebTabDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabDescriptionMetadata.b = function (a) {
        if (WebTabDescriptionMetadata.a == null) {
            WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
        }
        if (a.k(WebTabDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tab");
        a.item("__tagNameWC", "String:igc-tab");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Panel", "String");
        a.item("Selected", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebTabDescriptionMetadata.d = function (a) {
        WebTabDescriptionMetadata.b(a);
        a.ac("WebTab", function () { return new WebTabDescription(); });
        a.ab("WebTab", WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
}(Base));
export { WebTabDescriptionMetadata };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
var WebTabDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabDescriptionMetadata, _super);
    function WebTabDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabDescriptionMetadata.b = function (a) {
        if (WebTabDescriptionMetadata.a == null) {
            WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
        }
        if (a.k(WebTabDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tab");
        a.item("__tagNameWC", "String:igc-tab");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Label", "String");
        a.item("Selected", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebTabDescriptionMetadata.d = function (a) {
        WebTabDescriptionMetadata.b(a);
        a.ae("WebTab", function () { return new WebTabDescription(); });
        a.ad("WebTab", WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
}(Base));
export { WebTabDescriptionMetadata };
